# `plover` -- Program information

```{py:module} plover
```

```{data} _
:type: plover.i18n.Translator

A global instance of {class}`Translator<plover.i18n.Translator>`,
derived from the current system locale. Check {doc}`../i18n` for more
information on how to use this.
```

```{data} __version__
The full version string, for example `4.0.0.dev10`.
```

```{data} __copyright__
The copyright notice.
```

```{data} __url__
The URL to the Open Steno Project home page.
```

```{data} __download_url__
The URL to the Plover home page, where you can download Plover.
```

```{data} __credits__
Information on the creator of Plover and the list of Plover developers.
```

```{data} __license__
The name of the license Plover is licensed under.
```

```{data} __description__
A short description of Plover, not currently used.
```

```{data} __long_description__
An extended description of what Plover does, mainly used in the About screen.
```
